==> haskell-gridtables-0.1.0.0-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-EvOkK5wJmCdGXLr637unyj
key:                  gridtables-0.1.0.0-EvOkK5wJmCdGXLr637unyj
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  8886c8d6ddaceb33ee73c9a00fde690b
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-EvOkK5wJmCdGXLr637unyj
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-GIr1d5TiMlx5xKxDUxrl6T parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gridtables-0.1.0.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-E2BSJTxEf9493GGHCSHyaR
key:                  gridtables-0.1.0.0-E2BSJTxEf9493GGHCSHyaR
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  2c9f1d170427ad76a01e9f1b7d396db7
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-E2BSJTxEf9493GGHCSHyaR
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    doclayout-0.4.0.1-LaoXFXJLZPp8wgpltZ8ZtL parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
